@@ -23,8 +23,8 @@ except ImportError:
 
 
 class open(OpenBase):
-    def __init__(self, filename="", flags=None, rizin_home=None):
-        super(open, self).__init__(filename, flags)
+    def __init__(self, filename="", flags=None, rizin_home=None, **kwargs):
+        super(open, self).__init__(filename, flags, **kwargs)
         if flags is None:
             flags = []
         if filename.startswith("http://"):
@@ -46,7 +46,7 @@ class open(OpenBase):
             if rizin_home is not None:
                 if not os.path.isdir(rizin_home):
                     raise Exception(
-                        "`rizinhome` passed is invalid, leave it None or put a valid path to rizin folder"
+                        "`rizin_home` passed is invalid, leave it None or put a valid path to rizin folder"
                     )
                 rze = os.path.join(rizin_home, "rizin")
             else:
